<div class="flex items-center justify-center w-full h-full rounded">
    {% if type == 'txt' %}
    <i class="fas fa-file-alt text-4xl text-gray-600"></i>
    {% else %}
    <i class="fas fa-file text-4xl text-gray-600"></i>
    {% endif %}
</div>